[Telepathy-commits] [telepathy-gabble/master] Use the "channel manager" terminology everywhere instead of "channel factory"

Alban Crequy alban.crequy at collabora.co.uk
Fri Dec 5 09:42:39 PST 2008


---
 src/capabilities.c          |    6 ++--
 src/capabilities.h          |    2 +-
 src/caps-hash.c             |    2 +-
 src/connection.c            |   18 +++++++-------
 src/im-factory.c            |    2 +-
 src/media-factory.c         |    2 +-
 src/presence-cache.c        |   56 +++++++++++++++++++++---------------------
 src/presence-cache.h        |    8 +++---
 src/presence.c              |   56 +++++++++++++++++++++---------------------
 src/presence.h              |    4 +-
 src/private-tubes-factory.c |   14 +++++-----
 11 files changed, 85 insertions(+), 85 deletions(-)

diff --git a/src/capabilities.c b/src/capabilities.c
index f153a79..9bfc815 100644
--- a/src/capabilities.c
+++ b/src/capabilities.c
@@ -57,7 +57,7 @@ static const Feature self_advertised_features[] =
 
 GSList *
 capabilities_get_features (GabblePresenceCapabilities caps,
-                           GHashTable *per_channel_factory_caps)
+                           GHashTable *per_channel_manager_caps)
 {
   GHashTableIter channel_manager_iter;
   GabbleCapsChannelManager *manager;
@@ -69,9 +69,9 @@ capabilities_get_features (GabblePresenceCapabilities caps,
     if ((i->caps & caps) == i->caps)
       features = g_slist_append (features, (gpointer) i);
 
-  if (per_channel_factory_caps != NULL)
+  if (per_channel_manager_caps != NULL)
     {
-      g_hash_table_iter_init (&channel_manager_iter, per_channel_factory_caps);
+      g_hash_table_iter_init (&channel_manager_iter, per_channel_manager_caps);
       while (g_hash_table_iter_next (&channel_manager_iter,
                  (gpointer *) &manager, &cap))
         {
diff --git a/src/capabilities.h b/src/capabilities.h
index 1cb5fde..db8ede5 100644
--- a/src/capabilities.h
+++ b/src/capabilities.h
@@ -55,7 +55,7 @@ struct _Feature
  * GabblePresenceCapabilities.
  */
 GSList *capabilities_get_features (GabblePresenceCapabilities caps,
-    GHashTable *per_channel_factory_caps);
+    GHashTable *per_channel_manager_caps);
 
 /*
  * capabilities_fill_cache
diff --git a/src/caps-hash.c b/src/caps-hash.c
index 14ea622..10e77da 100644
--- a/src/caps-hash.c
+++ b/src/caps-hash.c
@@ -358,7 +358,7 @@ caps_hash_compute_from_self_presence (GabbleConnection *self)
 {
   GabblePresence *presence = self->self_presence;
   GSList *features_list = capabilities_get_features (presence->caps,
-      presence->per_channel_factory_caps);
+      presence->per_channel_manager_caps);
   GPtrArray *features = g_ptr_array_new ();
   GPtrArray *identities = g_ptr_array_new ();
   GPtrArray *dataforms = g_ptr_array_new ();
diff --git a/src/connection.c b/src/connection.c
index d5ccfb3..571da2f 100644
--- a/src/connection.c
+++ b/src/connection.c
@@ -1537,7 +1537,7 @@ connection_iq_disco_cb (LmMessageHandler *handler,
   lm_message_node_set_attribute (identity, "type", "pc");
 
   features = capabilities_get_features (self->self_presence->caps,
-      self->self_presence->per_channel_factory_caps);
+      self->self_presence->per_channel_manager_caps);
 
   DEBUG ("caps now %u", self->self_presence->caps);
 
@@ -2205,20 +2205,20 @@ _emit_contact_capabilities_changed (GabbleConnection *conn,
   tp_base_connection_channel_manager_iter_init (&iter, base_conn);
   while (tp_base_connection_channel_manager_iter_next (&iter, &manager))
     {
-      gpointer per_channel_factory_caps_old = NULL;
-      gpointer per_channel_factory_caps_new = NULL;
+      gpointer per_channel_manager_caps_old = NULL;
+      gpointer per_channel_manager_caps_new = NULL;
 
       /* all channel managers must implement the capability interface */
       g_assert (GABBLE_IS_CAPS_CHANNEL_MANAGER (manager));
 
       if (old_caps != NULL)
-        per_channel_factory_caps_old = g_hash_table_lookup (old_caps, manager);
+        per_channel_manager_caps_old = g_hash_table_lookup (old_caps, manager);
       if (new_caps != NULL)
-        per_channel_factory_caps_new = g_hash_table_lookup (new_caps, manager);
+        per_channel_manager_caps_new = g_hash_table_lookup (new_caps, manager);
 
       if (gabble_caps_channel_manager_capabilities_diff (
             GABBLE_CAPS_CHANNEL_MANAGER (manager), handle,
-            per_channel_factory_caps_old, per_channel_factory_caps_new))
+            per_channel_manager_caps_old, per_channel_manager_caps_new))
         {
           diff = TRUE;
           break;
@@ -2403,8 +2403,8 @@ gabble_connection_set_self_capabilities (
 
   /* reset the caps, and fill with the given parameter but keep a backup for
    * diffing: we don't want to emit a signal if nothing has changed */
-  save_caps = pres->per_channel_factory_caps;
-  pres->per_channel_factory_caps = NULL;
+  save_caps = pres->per_channel_manager_caps;
+  pres->per_channel_manager_caps = NULL;
 
   for (i = 0; i < caps->len; i++)
     {
@@ -2435,7 +2435,7 @@ gabble_connection_set_self_capabilities (
 
   _emit_contact_capabilities_changed (self, base->self_handle,
                                       save_caps,
-                                      pres->per_channel_factory_caps);
+                                      pres->per_channel_manager_caps);
   gabble_presence_cache_free_cache_entry (save_caps);
 
 
diff --git a/src/im-factory.c b/src/im-factory.c
index d94aa37..5ef8576 100644
--- a/src/im-factory.c
+++ b/src/im-factory.c
@@ -186,7 +186,7 @@ gabble_im_factory_class_init (GabbleImFactoryClass *gabble_im_factory_class)
 
   param_spec = g_param_spec_object ("connection", "GabbleConnection object",
                                     "Gabble connection object that owns this "
-                                    "IM channel factory object.",
+                                    "IM channel manager object.",
                                     GABBLE_TYPE_CONNECTION,
                                     G_PARAM_CONSTRUCT_ONLY |
                                     G_PARAM_READWRITE |
diff --git a/src/media-factory.c b/src/media-factory.c
index c7375a7..5d26b77 100644
--- a/src/media-factory.c
+++ b/src/media-factory.c
@@ -197,7 +197,7 @@ gabble_media_factory_class_init (GabbleMediaFactoryClass *gabble_media_factory_c
 
   param_spec = g_param_spec_object ("connection", "GabbleConnection object",
                                     "Gabble connection object that owns this "
-                                    "media channel factory object.",
+                                    "media channel manager object.",
                                     GABBLE_TYPE_CONNECTION,
                                     G_PARAM_CONSTRUCT_ONLY |
                                     G_PARAM_READWRITE |
diff --git a/src/presence-cache.c b/src/presence-cache.c
index 24061f1..9cd8602 100644
--- a/src/presence-cache.c
+++ b/src/presence-cache.c
@@ -218,7 +218,7 @@ struct _CapabilityInfo
    * At the moment, only GabblePrivateTubesFactory use this mechanism to store
    * the list of supported tube types (example: stream tube for daap).
    */
-  GHashTable *per_channel_factory_caps;
+  GHashTable *per_channel_manager_caps;
 
   TpIntSet *guys;
   guint trust;
@@ -251,7 +251,7 @@ capability_info_free (CapabilityInfo *info)
 static guint
 capability_info_recvd (GabblePresenceCache *cache, const gchar *node,
         TpHandle handle, GabblePresenceCapabilities caps,
-        GHashTable *per_channel_factory_caps, guint trust_inc)
+        GHashTable *per_channel_manager_caps, guint trust_inc)
 {
   CapabilityInfo *info = capability_info_get (cache, node);
 
@@ -264,7 +264,7 @@ capability_info_recvd (GabblePresenceCache *cache, const gchar *node,
        */
       tp_intset_clear (info->guys);
       info->caps = caps;
-      info->per_channel_factory_caps = per_channel_factory_caps;
+      info->per_channel_manager_caps = per_channel_manager_caps;
       info->trust = 0;
       info->caps_set = TRUE;
     }
@@ -732,14 +732,14 @@ free_caps_helper (gpointer key, gpointer value, gpointer user_data)
 
 void
 gabble_presence_cache_free_cache_entry (
-    GHashTable *per_channel_factory_caps)
+    GHashTable *per_channel_manager_caps)
 {
-  if (per_channel_factory_caps == NULL)
+  if (per_channel_manager_caps == NULL)
     return;
 
-  g_hash_table_foreach (per_channel_factory_caps, free_caps_helper,
+  g_hash_table_foreach (per_channel_manager_caps, free_caps_helper,
       NULL);
-  g_hash_table_destroy (per_channel_factory_caps);
+  g_hash_table_destroy (per_channel_manager_caps);
 }
 
 static void
@@ -806,7 +806,7 @@ _caps_disco_cb (GabbleDisco *disco,
   TpHandleRepoIface *contact_repo;
   gchar *full_jid = NULL;
   GabblePresenceCapabilities caps = 0;
-  GHashTable *per_channel_factory_caps;
+  GHashTable *per_channel_manager_caps;
   guint trust, trust_inc;
   TpHandle handle = 0;
   gboolean bad_hash = FALSE;
@@ -871,7 +871,7 @@ _caps_disco_cb (GabbleDisco *disco,
       goto OUT;
     }
 
-  per_channel_factory_caps = g_hash_table_new (NULL, NULL);
+  per_channel_manager_caps = g_hash_table_new (NULL, NULL);
 
   /* parsing for Connection.Interface.ContactCapabilities.DRAFT */
   tp_base_connection_channel_manager_iter_init (&iter, base_conn);
@@ -885,7 +885,7 @@ _caps_disco_cb (GabbleDisco *disco,
       factory_caps = gabble_caps_channel_manager_parse_capabilities
           (GABBLE_CAPS_CHANNEL_MANAGER (manager), query_result->children);
       if (factory_caps != NULL)
-        g_hash_table_insert (per_channel_factory_caps,
+        g_hash_table_insert (per_channel_manager_caps,
             GABBLE_CAPS_CHANNEL_MANAGER (manager), factory_caps);
     }
 
@@ -934,8 +934,8 @@ _caps_disco_cb (GabbleDisco *disco,
   if (handle == 0)
     {
       DEBUG ("Ignoring presence from invalid JID %s", jid);
-      gabble_presence_cache_free_cache_entry (per_channel_factory_caps);
-      per_channel_factory_caps = NULL;
+      gabble_presence_cache_free_cache_entry (per_channel_manager_caps);
+      per_channel_manager_caps = NULL;
       goto OUT;
     }
 
@@ -954,8 +954,8 @@ _caps_disco_cb (GabbleDisco *disco,
   if (NULL == waiter_self)
     {
       DEBUG ("Ignoring non requested disco reply");
-      gabble_presence_cache_free_cache_entry (per_channel_factory_caps);
-      per_channel_factory_caps = NULL;
+      gabble_presence_cache_free_cache_entry (per_channel_manager_caps);
+      per_channel_manager_caps = NULL;
       goto OUT;
     }
 
@@ -974,7 +974,7 @@ _caps_disco_cb (GabbleDisco *disco,
       if (g_str_equal (waiter_self->ver, computed_hash))
         {
           trust = capability_info_recvd (cache, node, handle, caps,
-              per_channel_factory_caps, trust_inc);
+              per_channel_manager_caps, trust_inc);
         }
       else
         {
@@ -983,8 +983,8 @@ _caps_disco_cb (GabbleDisco *disco,
               "our hash '%s'.", waiter_self->ver, computed_hash);
           trust = 0;
           bad_hash = TRUE;
-          gabble_presence_cache_free_cache_entry (per_channel_factory_caps);
-          per_channel_factory_caps = NULL;
+          gabble_presence_cache_free_cache_entry (per_channel_manager_caps);
+          per_channel_manager_caps = NULL;
         }
 
       g_free (computed_hash);
@@ -998,8 +998,8 @@ _caps_disco_cb (GabbleDisco *disco,
       /* Do not allow tubes caps if the contact does not observe XEP-0115
        * version 1.5: we don't need to bother being compatible with both version
        * 1.3 and tubes caps */
-      gabble_presence_cache_free_cache_entry (per_channel_factory_caps);
-      per_channel_factory_caps = NULL;
+      gabble_presence_cache_free_cache_entry (per_channel_manager_caps);
+      per_channel_manager_caps = NULL;
     }
 
   for (i = waiters; NULL != i;)
@@ -1025,18 +1025,18 @@ _caps_disco_cb (GabbleDisco *disco,
                 GabblePresenceCapabilities save_caps = presence->caps;
                 GHashTable *save_enhanced_caps;
                 gabble_presence_cache_copy_cache_entry (&save_enhanced_caps,
-                    presence->per_channel_factory_caps);
+                    presence->per_channel_manager_caps);
 
                 DEBUG ("setting caps for %d (thanks to %d %s) to "
                     "%d (save_caps %d)",
                     waiter->handle, handle, jid, caps, save_caps);
                 gabble_presence_set_capabilities (presence, waiter->resource,
-                    caps, per_channel_factory_caps, waiter->serial);
+                    caps, per_channel_manager_caps, waiter->serial);
                 DEBUG ("caps for %d (thanks to %d %s) now %d", waiter->handle,
                     handle, jid, presence->caps);
                 g_signal_emit (cache, signals[CAPABILITIES_UPDATE], 0,
                   waiter->handle, save_caps, presence->caps,
-                  save_enhanced_caps, presence->per_channel_factory_caps);
+                  save_enhanced_caps, presence->per_channel_manager_caps);
                 gabble_presence_cache_free_cache_entry (save_enhanced_caps);
               }
             }
@@ -1129,7 +1129,7 @@ _process_caps_uri (GabblePresenceCache *cache,
       if (presence)
         {
           gabble_presence_set_capabilities (presence, resource,
-              info->caps, info->per_channel_factory_caps, serial);
+              info->caps, info->per_channel_manager_caps, serial);
           DEBUG ("caps for %d (%s) now %d", handle, from, presence->caps);
         }
       else
@@ -1217,7 +1217,7 @@ _process_caps (GabblePresenceCache *cache,
     {
       old_caps = presence->caps;
       gabble_presence_cache_copy_cache_entry (&old_enhanced_caps,
-          presence->per_channel_factory_caps);
+          presence->per_channel_manager_caps);
     }
 
   for (i = uris; NULL != i; i = i->next)
@@ -1235,7 +1235,7 @@ _process_caps (GabblePresenceCache *cache,
 
       g_signal_emit (cache, signals[CAPABILITIES_UPDATE], 0,
           handle, old_caps, presence->caps, old_enhanced_caps,
-          presence->per_channel_factory_caps);
+          presence->per_channel_manager_caps);
       gabble_presence_cache_free_cache_entry (old_enhanced_caps);
     }
   else
@@ -1521,16 +1521,16 @@ gabble_presence_cache_do_update (
     presence = _cache_insert (cache, handle);
 
   caps_before = presence->caps;
-  enhanced_caps_before = presence->per_channel_factory_caps;
+  enhanced_caps_before = presence->per_channel_manager_caps;
   gabble_presence_cache_copy_cache_entry (&enhanced_caps_before,
-      presence->per_channel_factory_caps);
+      presence->per_channel_manager_caps);
 
   ret = gabble_presence_update (presence, resource, presence_id,
       status_message, priority);
 
   g_signal_emit (cache, signals[CAPABILITIES_UPDATE], 0, handle,
       caps_before, presence->caps, enhanced_caps_before,
-      presence->per_channel_factory_caps);
+      presence->per_channel_manager_caps);
   gabble_presence_cache_free_cache_entry (enhanced_caps_before);
 
   return ret;
diff --git a/src/presence.c b/src/presence.c
index d8381a1..777e618 100644
--- a/src/presence.c
+++ b/src/presence.c
@@ -41,7 +41,7 @@ typedef struct _Resource Resource;
 struct _Resource {
     gchar *name;
     GabblePresenceCapabilities caps;
-    GHashTable *per_channel_factory_caps;
+    GHashTable *per_channel_manager_caps;
     guint caps_serial;
     GabblePresenceId status;
     gchar *status_message;
@@ -60,7 +60,7 @@ _resource_new (gchar *name)
   Resource *new = g_slice_new0 (Resource);
   new->name = name;
   new->caps = PRESENCE_CAP_NONE;
-  new->per_channel_factory_caps = NULL;
+  new->per_channel_manager_caps = NULL;
   new->status = GABBLE_PRESENCE_OFFLINE;
   new->status_message = NULL;
   new->priority = 0;
@@ -75,11 +75,11 @@ _resource_free (Resource *resource)
 {
   g_free (resource->name);
   g_free (resource->status_message);
-  if (resource->per_channel_factory_caps != NULL)
+  if (resource->per_channel_manager_caps != NULL)
     {
       gabble_presence_cache_free_cache_entry
-        (resource->per_channel_factory_caps);
-      resource->per_channel_factory_caps = NULL;
+        (resource->per_channel_manager_caps);
+      resource->per_channel_manager_caps = NULL;
     }
 
   g_slice_free (Resource, resource);
@@ -95,11 +95,11 @@ gabble_presence_finalize (GObject *object)
   for (i = priv->resources; NULL != i; i = i->next)
     _resource_free (i->data);
 
-  if (presence->per_channel_factory_caps != NULL)
+  if (presence->per_channel_manager_caps != NULL)
     {
       gabble_presence_cache_free_cache_entry
-        (presence->per_channel_factory_caps);
-      presence->per_channel_factory_caps = NULL;
+        (presence->per_channel_manager_caps);
+      presence->per_channel_manager_caps = NULL;
     }
 
   g_slist_free (priv->resources);
@@ -199,20 +199,20 @@ void
 gabble_presence_set_capabilities (GabblePresence *presence,
                                   const gchar *resource,
                                   GabblePresenceCapabilities caps,
-                                  GHashTable *per_channel_factory_caps,
+                                  GHashTable *per_channel_manager_caps,
                                   guint serial)
 {
   GabblePresencePrivate *priv = GABBLE_PRESENCE_PRIV (presence);
   GSList *i;
 
   presence->caps = 0;
-  if (presence->per_channel_factory_caps != NULL)
+  if (presence->per_channel_manager_caps != NULL)
     {
       gabble_presence_cache_free_cache_entry
-        (presence->per_channel_factory_caps);
-      presence->per_channel_factory_caps = NULL;
+        (presence->per_channel_manager_caps);
+      presence->per_channel_manager_caps = NULL;
     }
-  presence->per_channel_factory_caps = g_hash_table_new (NULL, NULL);
+  presence->per_channel_manager_caps = g_hash_table_new (NULL, NULL);
 
   DEBUG ("about to add caps %u to resource %s with serial %u", caps, resource,
     serial);
@@ -239,24 +239,24 @@ gabble_presence_set_capabilities (GabblePresence *presence,
               tmp->caps |= caps;
               DEBUG ("resource %s caps now %u", resource, tmp->caps);
 
-              if (tmp->per_channel_factory_caps != NULL)
+              if (tmp->per_channel_manager_caps != NULL)
                 {
                   gabble_presence_cache_free_cache_entry
-                      (tmp->per_channel_factory_caps);
-                  tmp->per_channel_factory_caps = NULL;
+                      (tmp->per_channel_manager_caps);
+                  tmp->per_channel_manager_caps = NULL;
                 }
-              if (per_channel_factory_caps != NULL)
+              if (per_channel_manager_caps != NULL)
                 gabble_presence_cache_copy_cache_entry
-                    (&tmp->per_channel_factory_caps, per_channel_factory_caps);
+                    (&tmp->per_channel_manager_caps, per_channel_manager_caps);
             }
         }
 
       presence->caps |= tmp->caps;
 
-      if (tmp->per_channel_factory_caps != NULL)
+      if (tmp->per_channel_manager_caps != NULL)
         gabble_presence_cache_update_cache_entry
-            (presence->per_channel_factory_caps,
-             tmp->per_channel_factory_caps);
+            (presence->per_channel_manager_caps,
+             tmp->per_channel_manager_caps);
     }
 
   DEBUG ("total caps now %u", presence->caps);
@@ -332,13 +332,13 @@ gabble_presence_update (GabblePresence *presence,
           res = NULL;
 
           /* recalculate aggregate capability mask */
-          if (presence->per_channel_factory_caps != NULL)
+          if (presence->per_channel_manager_caps != NULL)
             {
               gabble_presence_cache_free_cache_entry
-                (presence->per_channel_factory_caps);
-              presence->per_channel_factory_caps = NULL;
+                (presence->per_channel_manager_caps);
+              presence->per_channel_manager_caps = NULL;
             }
-          presence->per_channel_factory_caps = g_hash_table_new (NULL, NULL);
+          presence->per_channel_manager_caps = g_hash_table_new (NULL, NULL);
           presence->caps = 0;
 
           for (i = priv->resources; i; i = i->next)
@@ -347,10 +347,10 @@ gabble_presence_update (GabblePresence *presence,
 
               presence->caps |= r->caps;
 
-              if (r->per_channel_factory_caps != NULL)
+              if (r->per_channel_manager_caps != NULL)
                 gabble_presence_cache_update_cache_entry
-                    (presence->per_channel_factory_caps,
-                     r->per_channel_factory_caps);
+                    (presence->per_channel_manager_caps,
+                     r->per_channel_manager_caps);
             }
         }
     }
diff --git a/src/presence.h b/src/presence.h
index 331b029..5543604 100644
--- a/src/presence.h
+++ b/src/presence.h
@@ -56,7 +56,7 @@ typedef struct _GabblePresencePrivate GabblePresencePrivate;
 struct _GabblePresence {
     GObject parent;
     GabblePresenceCapabilities caps;
-    GHashTable *per_channel_factory_caps;
+    GHashTable *per_channel_manager_caps;
     GabblePresenceId status;
     gchar *status_message;
     gchar *nickname;
@@ -81,7 +81,7 @@ gboolean gabble_presence_update (GabblePresence *presence,
 
 void gabble_presence_set_capabilities (GabblePresence *presence,
     const gchar *resource, GabblePresenceCapabilities caps,
-    GHashTable *per_channel_factory_caps, guint serial);
+    GHashTable *per_channel_manager_caps, guint serial);
 
 const gchar *gabble_presence_pick_resource_by_caps (GabblePresence *presence,
     GabblePresenceCapabilities caps);
diff --git a/src/private-tubes-factory.c b/src/private-tubes-factory.c
index a5523ad..21ee599 100644
--- a/src/private-tubes-factory.c
+++ b/src/private-tubes-factory.c
@@ -264,7 +264,7 @@ gabble_private_tubes_factory_class_init (
   param_spec = g_param_spec_object (
       "connection",
       "GabbleConnection object",
-      "Gabble connection object that owns this Tubes channel factory object.",
+      "Gabble connection object that owns this Tubes channel manager object.",
       GABBLE_TYPE_CONNECTION,
       G_PARAM_CONSTRUCT_ONLY |
       G_PARAM_READWRITE |
@@ -480,10 +480,10 @@ gabble_private_tubes_factory_get_contact_caps (
   if (presence == NULL)
     return;
 
-  if (presence->per_channel_factory_caps == NULL)
+  if (presence->per_channel_manager_caps == NULL)
     return;
 
-  caps = g_hash_table_lookup (presence->per_channel_factory_caps, manager);
+  caps = g_hash_table_lookup (presence->per_channel_manager_caps, manager);
   if (caps == NULL)
     return;
 
@@ -748,10 +748,10 @@ gabble_private_tubes_factory_add_cap (GabbleCapsChannelManager *manager,
 
   g_assert (presence != NULL);
 
-  if (presence->per_channel_factory_caps == NULL)
-    presence->per_channel_factory_caps = g_hash_table_new (NULL, NULL);
+  if (presence->per_channel_manager_caps == NULL)
+    presence->per_channel_manager_caps = g_hash_table_new (NULL, NULL);
 
-  caps = g_hash_table_lookup (presence->per_channel_factory_caps, manager);
+  caps = g_hash_table_lookup (presence->per_channel_manager_caps, manager);
   if (caps == NULL)
     {
       caps = g_new0 (TubesCapabilities, 1);
@@ -759,7 +759,7 @@ gabble_private_tubes_factory_add_cap (GabbleCapsChannelManager *manager,
           g_free, g_free);
       caps->dbus_tube_caps = g_hash_table_new_full (g_str_hash, g_str_equal,
           g_free, g_free);
-      g_hash_table_insert (presence->per_channel_factory_caps, manager, caps);
+      g_hash_table_insert (presence->per_channel_manager_caps, manager, caps);
     }
 
   if (!tp_strdiff (channel_type, GABBLE_IFACE_CHANNEL_TYPE_STREAM_TUBE))
diff --git a/src/presence-cache.h b/src/presence-cache.h
index 0619c0c..af9192d 100644
--- a/src/presence-cache.h
+++ b/src/presence-cache.h
@@ -85,17 +85,17 @@ void gabble_presence_cache_add_bundle_caps (GabblePresenceCache *cache,
 void gabble_presence_cache_really_remove (GabblePresenceCache *cache,
     TpHandle handle);
 
 /* loop on CapabilityInfo::per_channel_factory_caps and call
  * gabble_caps_channel_manager_free_capabilities */
 void gabble_presence_cache_free_cache_entry (
-    GHashTable *per_channel_factory_caps);
+    GHashTable *per_channel_manager_caps);
 
 /* loop on CapabilityInfo::per_channel_factory_caps and call
  * gabble_caps_channel_manager_copy_capabilities */
 void gabble_presence_cache_copy_cache_entry (GHashTable **out,
     GHashTable *in);
 
 /* loop on CapabilityInfo::per_channel_factory_caps and call
  * gabble_caps_channel_manager_update_capabilities */
 void gabble_presence_cache_update_cache_entry (GHashTable *out,
     GHashTable *in);
@@ -85,17 +85,17 @@ void gabble_presence_cache_add_bundle_caps (GabblePresenceCache *cache,
     TpHandle handle);
 
-/* loop on CapabilityInfo::per_channel_factory_caps and call
+/* loop on CapabilityInfo::per_channel_manager_caps and call
  * gabble_caps_channel_manager_free_capabilities */
 void gabble_presence_cache_free_cache_entry (
@@ -85,17 +85,17 @@ void gabble_presence_cache_add_bundle_caps (GabblePresenceCache *cache,
 
-/* loop on CapabilityInfo::per_channel_factory_caps and call
+/* loop on CapabilityInfo::per_channel_manager_caps and call
  * gabble_caps_channel_manager_copy_capabilities */
 void gabble_presence_cache_copy_cache_entry (GHashTable **out,
@@ -85,17 +85,17 @@ void gabble_presence_cache_add_bundle_caps (GabblePresenceCache *cache,
     GHashTable *in);
 
-/* loop on CapabilityInfo::per_channel_factory_caps and call
+/* loop on CapabilityInfo::per_channel_manager_caps and call
  * gabble_caps_channel_manager_update_capabilities */
 void gabble_presence_cache_update_cache_entry (GHashTable *out,
-- 
1.5.6.5




More information about the Telepathy-commits mailing list